<?php
/**
 * Product Details settings
 *
 * @package TheCartPress
 * @subpackage Appearance
 */

/**
 * This file is part of TheCartPress.
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

// Exit if accessed directly
if ( ! defined( 'ABSPATH' ) ) exit;

if ( ! class_exists( 'TCPThemeCompatibilitySettings' ) ) :

class TCPThemeCompatibilitySettings {

	private $updated = false;

	function __construct() {
		add_action( 'tcp_admin_menu', array( $this, 'tcp_admin_menu' ) );
	}

	function tcp_admin_menu( $thecartpress ) {
		if ( ! current_user_can( 'tcp_edit_settings' ) ) return;

		$base = $thecartpress->get_base_appearance();
		add_menu_page( '', __( 'Look&Feel', 'tcp' ), 'tcp_edit_settings', $base, '', plugins_url( 'thecartpress/images/tcp.png', TCP_FOLDER ), 40 );

		$page = add_submenu_page( $base, __( 'Theme Compatibility Settings', 'tcp' ), __( 'Theme Compatibility', 'tcp' ), 'tcp_edit_settings', $base, array( $this, 'admin_page' ) );
		add_action( "load-$page", array( $this, 'admin_load' ) );
		add_action( "load-$page", array( $this, 'admin_action' ) );
	}

	function admin_load() {
		get_current_screen()->add_help_tab( array(
			'id'	  => 'overview',
			'title'   => __( 'Overview' ),
			'content' =>
				'<p>' . __( 'Customize Theme Compatibility. Thanks to this feature, TheCartPress supports all themes.', 'tcp' ) . '</p>'
		) );

		get_current_screen()->set_help_sidebar(
			'<p><strong>' . __( 'For more information:', 'tcp' ) . '</strong></p>' .
			'<p>' . __( '<a href="http://thecartpress.com" target="_blank">Documentation on TheCartPress</a>', 'tcp' ) . '</p>' .
			'<p>' . __( '<a href="http://community.thecartpress.com/" target="_blank">Support Forums</a>', 'tcp' ) . '</p>' .
			'<p>' . __( '<a href="http://extend.thecartpress.com/" target="_blank">Extend site</a>', 'tcp' ) . '</p>'
		);
	}

	function admin_page() { ?>
<div class="wrap">
	<?php screen_icon( 'tcp-theme' ); ?><h2><?php _e( 'Theme Compatibility Settings', 'tcp' ); ?></h2>

<?php if ( !empty( $this->updated ) ) : ?>
	<div id="message" class="updated">
		<p><?php _e( 'Settings updated', 'tcp' ); ?></p>
	</div>
<?php endif; ?>

<?php global $thecartpress;
if ( isset( $_REQUEST['current_post_type'] ) && strlen( trim( $_REQUEST['current_post_type'] ) ) > 0 ) {
	$current_post_type = $_REQUEST['current_post_type'];
	$suffix = '-' . $current_post_type;
} else {
	$suffix = '';
	$current_post_type = '';
}

$load_default_buy_button_style				= $thecartpress->get_setting( 'load_default_buy_button_style', true );
$load_default_shopping_cart_checkout_style	= $thecartpress->get_setting( 'load_default_shopping_cart_checkout_style', true );
$load_default_loop_style					= $thecartpress->get_setting( 'load_default_loop_style', true );
$load_bootstrap_js							= $thecartpress->get_setting( 'load_bootstrap_js', true );

// since 1.3.8
$search_only_products = $thecartpress->get_setting( 'search_only_products', false );

// since 1.5.0
$use_custom_login_ver_two = $thecartpress->get_setting( 'use_custom_login_ver_two', false );

// By post type 
$products_per_page			= $thecartpress->get_setting( 'products_per_page' . $suffix, '10' );
$image_size_grouped_by_button		= $thecartpress->get_setting( 'image_size_grouped_by_button' . $suffix, 'thumbnail' );
$image_size_content			= $thecartpress->get_setting( 'image_size_content' . $suffix, 'medium' );
//$image_align_content			= $thecartpress->get_setting( 'image_align_content' . $suffix );
//$image_link_content			= $thecartpress->get_setting( 'image_link_content' . $suffix );

// since 1.5.0
$see_product_thumbnail = $thecartpress->get_setting( 'see_product_thumbnail' . $suffix, true );
?>

<form method="post" action="">

<h3><?php _e( 'TheCartPress Styles', 'tcp' ); ?></h3>

<p class="description"><?php _e( 'Allows to load default styles provided by TheCartPress. To create your own styles, deactivate these settings. You could, also, customise by copying these CSS files to your theme.', 'tcp' ); ?></p>

<div class="postbox">
<div class="inside">
<table class="form-table">
<tbody>

<tr valign="top">
	<th scope="row">
		<label for="load_default_buy_button_style"><?php _e( 'Load default Buy Button styles', 'tcp' ); ?></label>
	</th>
	<td>
		<input type="checkbox" id="load_default_buy_button_style" name="load_default_buy_button_style" value="yes" <?php checked( true, $load_default_buy_button_style ); ?> />
	</td>
</tr>

<tr valign="top">
	<th scope="row">
		<label for="load_default_shopping_cart_checkout_style"><?php _e( 'Load default Shopping Cart & Checkout styles', 'tcp' ); ?></label>
	</th>
	<td>
		<input type="checkbox" id="load_default_shopping_cart_checkout_style" name="load_default_shopping_cart_checkout_style" value="yes" <?php checked( true, $load_default_shopping_cart_checkout_style ); ?> />
	</td>
</tr>

<tr valign="top">
	<th scope="row">
		<label for="load_default_loop_style"><?php _e( 'Load default Catalogue styles', 'tcp' ); ?></label>
	</th>
	<td>
		<input type="checkbox" id="load_default_loop_style" name="load_default_loop_style" value="yes" <?php checked( true, $load_default_loop_style ); ?> />
	</td>
</tr>

<tr valign="top">
	<th scope="row">
		<label for="load_default_loop_style"><?php _e( 'Load Bootstrap JavaScript', 'tcp' ); ?></label>
	</th>
	<td>
		<input type="checkbox" id="load_bootstrap_js" name="load_bootstrap_js" value="yes" <?php checked( true, $load_bootstrap_js ); ?> />
	</td>
</tr>

<tr valign="top">
	<th scope="row">
		<label for="products_per_page"><?php _e( 'Product pages show at most', 'tcp' ); ?></label>
	</th>
	<td>
		<input type="text" id="products_per_page" name="products_per_page" value="<?php echo $products_per_page; ?>" class="small-text tcp_count" maxlength="4" />
		<?php _e( 'products', 'tcp'); ?>
	</td>
</tr>

<tr valign="top">
	<th scope="row">
		<label for="use_custom_login_ver_two"><?php _e( 'Use custom login ver. 2', 'tcp' ); ?></label>
	</th>
	<td>
		<input type="checkbox" id="use_custom_login_ver_two" name="use_custom_login_ver_two" <?php checked( $use_custom_login_ver_two ); ?> value="yes" />
	</td>
</tr>

</tbody>
</table>
</div><!-- .inside -->
</div>

<?php do_action( 'tcp_theme_compatibility_settings_page_top', $suffix, $thecartpress ); ?>

<h3 class="hndle"><?php _e( 'How to display Product Details', 'tcp' ); ?></h3>

<div class="postbox">
<div class="inside">
<table class="form-table">
<tbody>

<tr valign="top">
	<th scope="row">
		<label for="current_post_type"><?php _e( 'Post type', 'tcp' ); ?></label>
	</th>
	<td class="tcpf">
		<?php $post_types = get_post_types( '', 'object' ); ?>
		<p>
			<select id="current_post_type" name="current_post_type">
				<option value="" <?php selected( true, $current_post_type ); ?>><?php _e( 'Default', 'tcp'); ?></option>
				<?php foreach( $post_types as $i => $post_type ) : 
					//$existe = $thecartpress->get_setting( 'image_size_grouped_by_button-' . $i, 'false' ) !== 'false';
					$existe = $thecartpress->get_setting( 'image_size_content-' . $i, 'false' ) !== 'false'; ?>
				<option value="<?php echo $i; ?>" <?php selected( $i, $current_post_type ); ?>
				<?php if ( $existe ) : ?> style="font-weight: bold;"<?php endif; ?>
				>
				<?php echo $post_type->labels->singular_name; ?><?php if ( $thecartpress->get_setting( 'image_size_content-' . $i, false ) !== false ) : ?> (*)<?php endif; ?>
				<?php if ( $existe ) : ?> *<?php endif; ?>
				</option>
				<?php endforeach; ?>
			</select>
			<input type="submit" name="load_post_type_settings" value="<?php _e( 'Load post type settings', 'tcp' ); ?>" class="button-secondary"/>
			<input type="submit" name="delete_post_type_settings" value="<?php _e( 'Delete post type settings', 'tcp' ); ?>" class="button-secondary"/>
		</p>
		<?php $config = '';
		foreach( $post_types as $i => $post_type ) {
			if ( $thecartpress->get_setting( 'image_size_content-' . $i, false ) !== false ) {
				$line = '<li>' . $post_type->labels->singular_name;
				$line .= ': <a href="' . add_query_arg( 'current_post_type', $i ) . '">' . __( 'Load settings', 'tcp' ) . '</span></a>';
				$line .= '</li>';
				$config .= $line;
			}
		} ?>
		<?php if ( strlen( $config ) > 0 ) : ?>
		<div class="alert alert-warning">
			<?php  _e( 'There are specific settings for the next Post Types:', 'tcp' ); ?>
			<ul style="padding-left:10px;">
				<?php echo $config; ?>
				<li><a href="<?php echo remove_query_arg( 'current_post_type' ); ?>"><?php _e( 'Load default settings', 'tcp' ); ?></a></li>
			</ul>
		</div>
		<?php endif; ?>

		<p class="description"><?php _e( 'Allows to create different configuration for each Post Type.', 'tcp' ); ?></p>
		<span class="description"><?php _e( 'Options in bold have a specific configuration.', 'tcp' ); ?>
		<?php _e( 'Remember to save the changes before to load new post type settings.', 'tcp' ); ?>
		</span>

	</td>
</tr>

<?php $image_sizes = get_intermediate_image_sizes(); ?>

<tr valign="top">
	<th scope="row">
	<label for="image_size_grouped_by_button"><?php _e( 'Image size grouped buy button', 'tcp' ); ?></label>
	</th>
	<td>
		<select id="image_size_grouped_by_button" name="image_size_grouped_by_button">
			<option value="none" <?php selected( 'none', $image_size_grouped_by_button ); ?>><?php _e( 'No image', 'tcp' ); ?></option>
			<?php foreach( $image_sizes as $image_size ) : ?>
			<option value="<?php echo $image_size; ?>" <?php selected( $image_size, $image_size_grouped_by_button ); ?>><?php echo $image_size; ?></option>
			<?php endforeach; ?>
			<option value="64" <?php selected( '64', $image_size_grouped_by_button ); ?>><?php _e( '64x64', 'tcp' ); ?></option>
			<option value="48" <?php selected( '48', $image_size_grouped_by_button ); ?>><?php _e( '48x48', 'tcp' ); ?></option>
			<option value="32" <?php selected( '32', $image_size_grouped_by_button ); ?>><?php _e( '32x32', 'tcp' ); ?></option>
		</select>
		<p class="description"><?php _e( 'allows to select the size of the image to show in grouped products.', 'tcp' ); ?></p>
	</td>
</tr>

<tr valign="top">
	<th scope="row">
	<label for="see_product_thumbnail"><?php _e( 'See product thumbnail', 'tcp' ); ?></label>
	</th>
	<td>
		<input type="checkbox" id="see_product_thumbnail" name="see_product_thumbnail" value="yes" <?php checked( $see_product_thumbnail ); ?> />
	</td>
</tr>

<tr valign="top">
	<th scope="row">
	<label for="image_size_content"><?php _e( 'Product image size', 'tcp' ); ?></label>
	</th>
	<td>
		<select id="image_size_content" name="image_size_content">
		<?php foreach( $image_sizes as $image_size ) : ?>
			<option value="<?php echo $image_size; ?>" <?php selected( $image_size, $image_size_content ); ?>><?php echo $image_size; ?></option>
		<?php endforeach; ?>
		</select>
	</td>
</tr>

<!--<tr valign="top">
	<th scope="row">
	<label for="image_align_content"><?php _e( 'Image align in content', 'tcp' ); ?></label>
	</th>
	<td>
		<select id="image_align_content" name="image_align_content">
			<option value="" <?php selected( '', $image_align_content ); ?>><?php _e( 'None', 'tcp' ); ?></option>
			<option value="alignleft" <?php selected( 'alignleft', $image_align_content ); ?>><?php _e( 'Align Left', 'tcp' ); ?></option>
			<option value="aligncenter" <?php selected( 'aligncenter', $image_align_content ); ?>><?php _e( 'Align Center', 'tcp' ); ?></option>
			<option value="alignright" <?php selected( 'alignright', $image_align_content ); ?>><?php _e( 'Align Right', 'tcp' ); ?></option>
		</select>
	</td>
</tr>-->

<!--<tr valign="top">
	<th scope="row">
	<label for="image_link_content"><?php _e( 'Image link in content', 'tcp' ); ?></label>
	</th>
	<td>
		<select id="image_link_content" name="image_link_content">
			<option value="" <?php selected( '', $image_link_content ); ?>><?php _e( 'None', 'tcp' ); ?></option>
			<option value="file" <?php selected( 'file', $image_link_content ); ?>><?php _e( 'File url', 'tcp' ); ?></option>
			<option value="post" <?php selected( 'post', $image_link_content ); ?>><?php _e( 'Post url', 'tcp' ); ?></option>
		</select>
	</td>
</tr>-->

</tbody>
</table>

</div><!-- .inside -->
</div><!-- .postbox -->

<h3><?php _e( 'TheCartPress Search', 'tcp' ); ?></h3>

<p class="description"><?php _e( 'Allows to define what to search. This option could not be compatible with all themes.', 'tcp' ); ?></p>

<div class="postbox">
<div class="inside">
<table class="form-table">
<tbody>

<tr valign="top">
	<th scope="row">
		<label for="search_only_products"><?php _e( 'Search only products', 'tcp' ); ?>:</label>
	</th>
	<td>
		<input type="checkbox" id="search_only_products" name="search_only_products" value="yes" <?php checked( $search_only_products ); ?> />
	</td>
</tr>

</tbody>
</table>

</div><!-- .inside -->
</div><!-- .postbox -->
<?php do_action( 'tcp_theme_compatibility_settings_page', $suffix, $thecartpress ); ?>

<?php wp_nonce_field( 'tcp_theme_compatibility_settings' ); ?>
<?php submit_button( null, 'primary', 'save-theme_compatibility-settings' ); ?>
</form>
</div><!-- .wrap -->
<?php
	}

	function admin_action() {
		if ( empty( $_POST ) ) return;
		check_admin_referer( 'tcp_theme_compatibility_settings' );
		if ( isset( $_POST['load_post_type_settings'] ) ) return;
		if ( isset( $_POST['current_post_type'] )  && strlen( $_POST['current_post_type'] ) > 0 ) {
			$suffix = '-' . $_POST['current_post_type'];
		} else {
			$suffix = '';
		}
		if ( isset( $_POST['delete_post_type_settings'] ) ) {
			if ( empty( $suffix ) ) return;
			$settings = get_option( 'tcp_settings' );
			unset( $settings['products_per_page' . $suffix] );
			unset( $settings['image_size_grouped_by_button' . $suffix] );
			unset( $settings['see_product_thumbnail' . $suffix] );
			unset( $settings['image_size_content' . $suffix] );
			$settings = apply_filters( 'tcp_theme_compatibility_unset_settings_action', $settings, $suffix );
			update_option( 'tcp_settings', $settings );
			$this->updated = true;
			global $thecartpress;
			$thecartpress->load_settings();
			return;
		}
		$settings = get_option( 'tcp_settings' );

		$settings['load_default_buy_button_style']			= isset( $_POST['load_default_buy_button_style'] ) ? $_POST['load_default_buy_button_style'] == 'yes' : false;
		$settings['load_default_shopping_cart_checkout_style'] = isset( $_POST['load_default_shopping_cart_checkout_style'] ) ? $_POST['load_default_shopping_cart_checkout_style'] == 'yes' : false;
		$settings['load_default_loop_style']				= isset( $_POST['load_default_loop_style'] ) ? $_POST['load_default_loop_style'] == 'yes' : false;
		$settings['load_bootstrap_js']						= isset( $_POST['load_bootstrap_js'] );
		$settings['products_per_page' . $suffix]			= isset( $_POST[ 'products_per_page' ] ) ? $_POST[ 'products_per_page' ] : false;

		$settings['image_size_grouped_by_button' . $suffix]	= isset( $_POST['image_size_grouped_by_button'] ) ? $_POST['image_size_grouped_by_button'] : 'thumbnail';
		$settings['see_product_thumbnail' . $suffix]		= isset( $_POST['see_product_thumbnail'] );
		$settings['image_size_content' . $suffix]			= isset( $_POST['image_size_content'] ) ? $_POST['image_size_content'] : 'thumbnail';
		//$settings['image_align_content' . $suffix]			= isset( $_POST['image_align_content'] ) ? $_POST['image_align_content'] : 'north';
		//$settings['image_link_content' . $suffix]			= isset( $_POST['image_link_content'] ) ? $_POST['image_link_content'] : '';
		$settings['search_only_products']					= isset( $_POST['search_only_products'] );
		$settings['use_custom_login_ver_two']				= isset( $_POST['use_custom_login_ver_two'] );

		$settings = apply_filters( 'tcp_theme_compatibility_settings_action', $settings, $suffix );

		update_option( 'tcp_settings', $settings );
		$this->updated = true;
		global $thecartpress;
		$thecartpress->load_settings();
	}
}

new TCPThemeCompatibilitySettings();
endif; // class_exists check
